@@ -38,7 +38,6 @@ public:
 
     ~AutoCorrectionWidgetPrivate()
     {
-        delete ui;
     }
 
     AutoCorrection::TypographicQuotes m_singleQuotes;
@@ -46,7 +45,7 @@ public:
     QSet<QString> m_upperCaseExceptions;
     QSet<QString> m_twoUpperLetterExceptions;
     QHash<QString, QString> m_autocorrectEntries;
-    Ui::AutoCorrectionWidget *const ui;
+    std::unique_ptr<Ui::AutoCorrectionWidget> const ui;
     AutoCorrection *mAutoCorrection = nullptr;
     bool mWasChanged = false;
 };
@@ -105,7 +104,7 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     connect(d->ui->abbreviationList, &PimCommon::AutoCorrectionListWidget::deleteSelectedItems, this, &AutoCorrectionWidget::removeAbbreviationEntry);
     connect(d->ui->twoUpperLetterList, &PimCommon::AutoCorrectionListWidget::itemSelectionChanged, this, &AutoCorrectionWidget::slotEnableDisableTwoUpperEntry);
     connect(d->ui->twoUpperLetterList, &PimCommon::AutoCorrectionListWidget::deleteSelectedItems, this, &AutoCorrectionWidget::removeTwoUpperLetterEntry);
-    connect(d->ui->autocorrectionLanguage, QOverload<int>::of(&PimCommon::AutoCorrectionLanguage::activated), this, &AutoCorrectionWidget::changeLanguage);
+    connect(d->ui->autocorrectionLanguage, &PimCommon::AutoCorrectionLanguage::activated, this, &AutoCorrectionWidget::changeLanguage);
     connect(d->ui->addNonBreakingSpaceInFrench, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->twoUpperLetter, &QLineEdit::returnPressed, this, &AutoCorrectionWidget::addTwoUpperLetterEntry);
     connect(d->ui->abbreviation, &QLineEdit::returnPressed, this, &AutoCorrectionWidget::addAbbreviationEntry);
@@ -128,10 +127,7 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     connect(d->ui->exportAutoCorrection, &QPushButton::clicked, this, &AutoCorrectionWidget::slotExportAutoCorrection);
 }
 
-AutoCorrectionWidget::~AutoCorrectionWidget()
-{
-    delete d;
-}
+AutoCorrectionWidget::~AutoCorrectionWidget() = default;
 
 void AutoCorrectionWidget::setAutoCorrection(AutoCorrection *autoCorrect)
 {
@@ -606,7 +602,11 @@ void AutoCorrectionWidget::changeLanguage(int index)
         return;
     }
     if (d->mWasChanged) {
-        const int rc = KMessageBox::warningYesNo(this, i18n("Language was changed, do you want to save config for previous language?"), i18n("Save config"));
+        const int rc = KMessageBox::warningYesNo(this,
+                                                 i18n("Language was changed, do you want to save config for previous language?"),
+                                                 i18n("Save config"),
+                                                 KStandardGuiItem::save(),
+                                                 KStandardGuiItem::discard());
         if (rc == KMessageBox::Yes) {
             writeConfig();
         }
