@@ -1,35 +1,24 @@
 /*
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AutoCorrectionWidget_H
-#define AutoCorrectionWidget_H
+#pragma once
 
-#include "pimcommon_export.h"
 #include "pimcommon/autocorrection.h"
+#include "pimcommon_export.h"
 #include <QWidget>
 
 class QTreeWidgetItem;
 
-namespace Ui {
+namespace Ui
+{
 class AutoCorrectionWidget;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class AutoCorrectionWidgetPrivate;
 /**
  * @brief The AutoCorrectionWidget class
@@ -40,13 +29,10 @@ class PIMCOMMON_EXPORT AutoCorrectionWidget : public QWidget
     Q_OBJECT
 
 public:
-    enum ImportFileType {
-        LibreOffice,
-        KMail
-    };
+    enum ImportFileType { LibreOffice, KMail };
 
     explicit AutoCorrectionWidget(QWidget *parent = nullptr);
-    ~AutoCorrectionWidget();
+    ~AutoCorrectionWidget() override;
     void setAutoCorrection(AutoCorrection *autoCorrect);
     void loadConfig();
     void writeConfig();
@@ -98,8 +84,7 @@ private:
     void loadGlobalAutoCorrectionAndException();
     void setLanguage(const QString &lang);
 
-    AutoCorrectionWidgetPrivate *const d;
+    std::unique_ptr<AutoCorrectionWidgetPrivate> const d;
 };
 }
 
-#endif // AutoCorrectionWidget_H
