@@ -1,31 +1,19 @@
 /*
-  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AUTOCORRECTIONTEST_H
-#define AUTOCORRECTIONTEST_H
+#pragma once
 
-#include <QObject>
 #include <KSharedConfig>
+#include <QObject>
 class AutoCorrectionTest : public QObject
 {
     Q_OBJECT
 public:
     AutoCorrectionTest();
-    ~AutoCorrectionTest();
+    ~AutoCorrectionTest() override;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
@@ -59,4 +47,3 @@ private:
     KSharedConfig::Ptr mConfig;
 };
 
-#endif // AUTOCORRECTIONTEST_H
