@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "autocorrection_gui.h"
@@ -23,24 +12,22 @@
 
 #include "pimcommon_debug.h"
 
-#include <KSharedConfig>
-
-#include <QPointer>
-#include <QVBoxLayout>
-#include <QPushButton>
-#include <QKeyEvent>
-#include <QToolBar>
 #include <QAction>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDialogButtonBox>
+#include <QKeyEvent>
+#include <QPointer>
+#include <QPushButton>
+#include <QToolBar>
+#include <QVBoxLayout>
 
 ConfigureTestDialog::ConfigureTestDialog(PimCommon::AutoCorrection *autoCorrection, QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(QStringLiteral("Configure Autocorrection"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto mainLayout = new QVBoxLayout(this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -99,17 +86,17 @@ void TextEditAutoCorrectionWidget::keyPressEvent(QKeyEvent *e)
 
 AutocorrectionTestWidget::AutocorrectionTestWidget(QWidget *parent)
     : QWidget(parent)
+    , mConfig(KSharedConfig::openConfig(QStringLiteral("autocorrectionguirc")))
 {
-    mConfig = KSharedConfig::openConfig(QStringLiteral("autocorrectionguirc"));
     PimCommon::PimCommonSettings::self()->setSharedConfig(mConfig);
     PimCommon::PimCommonSettings::self()->load();
 
     mAutoCorrection = new PimCommon::AutoCorrection;
-    QVBoxLayout *lay = new QVBoxLayout(this);
-    QToolBar *bar = new QToolBar;
+    auto lay = new QVBoxLayout(this);
+    auto bar = new QToolBar;
     lay->addWidget(bar);
     bar->addAction(QStringLiteral("Configure..."), this, &AutocorrectionTestWidget::slotConfigure);
-    QAction *richText = new QAction(QStringLiteral("HTML mode"), this);
+    auto richText = new QAction(QStringLiteral("HTML mode"), this);
     richText->setCheckable(true);
     connect(richText, &QAction::toggled, this, &AutocorrectionTestWidget::slotChangeMode);
     bar->addAction(richText);
@@ -151,7 +138,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    AutocorrectionTestWidget *w = new AutocorrectionTestWidget();
+    auto w = new AutocorrectionTestWidget();
     w->resize(800, 600);
 
     w->show();
