@@ -1,42 +1,31 @@
 /*
-  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "configurepluginslistwidget.h"
 
-#include <KSharedConfig>
 #include <KLocalizedString>
+#include <KSharedConfig>
+#include <KTreeWidgetSearchLineWidget>
 
+#include <QAction>
+#include <QHeaderView>
 #include <QPushButton>
 #include <QToolButton>
 #include <QTreeWidget>
-#include <QHeaderView>
-#include <QAction>
 #include <QVBoxLayout>
 
 using namespace PimCommon;
 ConfigurePluginsListWidget::ConfigurePluginsListWidget(QWidget *parent)
     : QWidget(parent)
+    , mListWidget(new QTreeWidget(this))
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setContentsMargins({});
 
-    mListWidget = new QTreeWidget(this);
     mListWidget->setSortingEnabled(true);
     mListWidget->sortItems(0, Qt::AscendingOrder);
     mListWidget->setObjectName(QStringLiteral("listwidget"));
@@ -44,10 +33,16 @@ ConfigurePluginsListWidget::ConfigurePluginsListWidget(QWidget *parent)
     mListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
     mListWidget->setColumnCount(2);
     mListWidget->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
+    mListWidget->header()->setSectionResizeMode(1, QHeaderView::ResizeToContents);
+    mListWidget->header()->setStretchLastSection(false);
+
+    mTreeWidgetSearchLineEdit = new KTreeWidgetSearchLineWidget(this, mListWidget);
+    mTreeWidgetSearchLineEdit->setObjectName(QStringLiteral("mTreeWidgetSearchLineEdit"));
 
     connect(mListWidget, &QTreeWidget::itemSelectionChanged, this, &ConfigurePluginsListWidget::slotItemSelectionChanged);
     connect(mListWidget, &QTreeWidget::itemChanged, this, &ConfigurePluginsListWidget::slotItemChanged);
 
+    mainLayout->addWidget(mTreeWidgetSearchLineEdit);
     mainLayout->addWidget(mListWidget);
 }
 
@@ -57,7 +52,7 @@ ConfigurePluginsListWidget::~ConfigurePluginsListWidget()
 
 void ConfigurePluginsListWidget::slotItemChanged(QTreeWidgetItem *item, int column)
 {
-    Q_UNUSED(item);
+    Q_UNUSED(item)
     if (mInitializeDone) {
         if (column == 0) {
             Q_EMIT changed();
@@ -68,7 +63,7 @@ void ConfigurePluginsListWidget::slotItemChanged(QTreeWidgetItem *item, int colu
 void ConfigurePluginsListWidget::slotItemSelectionChanged()
 {
     QTreeWidgetItem *item = mListWidget->currentItem();
-    if (PluginItem *pluginItem = dynamic_cast<PluginItem *>(item)) {
+    if (auto pluginItem = dynamic_cast<PluginItem *>(item)) {
         Q_EMIT descriptionChanged(pluginItem->mDescription);
     }
 }
@@ -114,20 +109,24 @@ void ConfigurePluginsListWidget::savePlugins(const QString &groupName, const QSt
             disabledPlugins << item->mIdentifier;
         }
     }
-    PimCommon::PluginUtil::savePluginSettings(groupName,
-                                              prefixSettingKey,
-                                              enabledPlugins, disabledPlugins);
+    PimCommon::PluginUtil::savePluginSettings(groupName, prefixSettingKey, enabledPlugins, disabledPlugins);
 }
 
-void ConfigurePluginsListWidget::fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName, const QString &groupName, const QString &prefixKey, QVector<PluginItem *> &itemsList, const QString &configureGroupName, bool checkable)
+void ConfigurePluginsListWidget::fillTopItems(const QVector<PimCommon::PluginUtilData> &lst,
+                                              const QString &topLevelItemName,
+                                              const QString &groupName,
+                                              const QString &prefixKey,
+                                              QVector<PluginItem *> &itemsList,
+                                              const QString &configureGroupName,
+                                              bool checkable)
 {
     itemsList.clear();
     if (!lst.isEmpty()) {
-        QTreeWidgetItem *topLevel = new QTreeWidgetItem(mListWidget, {topLevelItemName});
+        auto topLevel = new QTreeWidgetItem(mListWidget, {topLevelItemName});
         topLevel->setFlags(topLevel->flags() & ~Qt::ItemIsSelectable);
         const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(groupName, prefixKey);
         for (const PimCommon::PluginUtilData &data : lst) {
-            PluginItem *subItem = new PluginItem(topLevel);
+            auto subItem = new PluginItem(topLevel);
             subItem->setText(0, data.mName);
             subItem->mIdentifier = data.mIdentifier;
             subItem->mDescription = data.mDescription;
@@ -139,11 +138,9 @@ void ConfigurePluginsListWidget::fillTopItems(const QVector<PimCommon::PluginUti
                 subItem->setCheckState(0, isPluginActivated ? Qt::Checked : Qt::Unchecked);
             }
             if (data.mHasConfigureDialog) {
-                QToolButton *but = new QToolButton(mListWidget);
-                QAction *act = new QAction(but);
-                const QStringList actData {
-                    configureGroupName, data.mIdentifier
-                };
+                auto but = new QToolButton(mListWidget);
+                auto act = new QAction(but);
+                const QStringList actData{configureGroupName, data.mIdentifier};
                 act->setData(actData);
                 but->setDefaultAction(act);
                 but->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
