@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -27,7 +27,7 @@ void ActionTypeTest::shouldHaveDefaultValue()
 
 void ActionTypeTest::shouldAssignValue()
 {
-    auto *act = new QAction(nullptr);
+    auto act = new QAction(nullptr);
     PimCommon::ActionType::Type type = PimCommon::ActionType::File;
     PimCommon::ActionType actionType(act, type);
     QCOMPARE(actionType.action(), act);
