@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "pluginutiltest.h"
@@ -36,24 +25,20 @@ void PluginUtilTest::shouldTestIsEnabled_data()
     QTest::addColumn<QString>("pluginId");
     QTest::addColumn<bool>("result");
 
-    //Use default value
+    // Use default value
     QTest::newRow("emptysettings") << QStringList() << QStringList() << true << QStringLiteral("foo") << true;
     QTest::newRow("emptysettings-2") << QStringList() << QStringList() << false << QStringLiteral("foo") << false;
 
-    //Return false each time that pluginid is empty
+    // Return false each time that pluginid is empty
     QTest::newRow("pluginidempty") << QStringList() << QStringList() << true << QString() << false;
     QTest::newRow("pluginidempty-2") << QStringList() << QStringList() << false << QString() << false;
 
-    //Use setting from user settings
-    QStringList disabled{
-        QStringLiteral("foo")
-    };
+    // Use setting from user settings
+    QStringList disabled{QStringLiteral("foo")};
     QTest::newRow("usersettingdisabled") << QStringList() << disabled << true << QStringLiteral("foo") << false;
     QTest::newRow("usersettingdisabled-2") << QStringList() << disabled << false << QStringLiteral("foo") << false;
 
-    QStringList enabled{
-        QStringLiteral("foo")
-    };
+    QStringList enabled{QStringLiteral("foo")};
     QTest::newRow("usersettingenabled") << enabled << QStringList() << true << QStringLiteral("foo") << true;
     QTest::newRow("usersettingenabled-2") << enabled << QStringList() << false << QStringLiteral("foo") << true;
 }
