@@ -1,25 +1,13 @@
 /*
-  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "logactivitiesmanager.h"
 #include "logactivitiesdialog.h"
-#include <QTime>
 #include <QPointer>
+#include <QTime>
 
 using namespace PimCommon;
 
@@ -29,15 +17,13 @@ class PimCommon::LogActivitiesManagerPrivate
 {
 public:
     LogActivitiesManagerPrivate()
-        : mDialog{nullptr}
-        , mEnableLogActivities{false}
     {
     }
 
     ~LogActivitiesManagerPrivate()
     {
-        //Disable delete it.
-        //delete mDialog;
+        // Disable delete it.
+        // delete mDialog;
     }
 
     QStringList mLog;
@@ -51,10 +37,7 @@ LogActivitiesManager::LogActivitiesManager(QObject *parent)
 {
 }
 
-LogActivitiesManager::~LogActivitiesManager()
-{
-    delete d;
-}
+LogActivitiesManager::~LogActivitiesManager() = default;
 
 LogActivitiesManager *LogActivitiesManager::self()
 {
