@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIGRATEAPPLICATIONFILESTEST_H
-#define MIGRATEAPPLICATIONFILESTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class MigrateApplicationFilesTest : public QObject
     Q_OBJECT
 public:
     explicit MigrateApplicationFilesTest(QObject *parent = nullptr);
-    ~MigrateApplicationFilesTest();
+    ~MigrateApplicationFilesTest() override;
 private Q_SLOTS:
     void initTestCase();
     void shouldHaveDefaultValue();
@@ -31,4 +30,3 @@ private Q_SLOTS:
     void shouldNotMigrateIfAlreadyDone();
 };
 
-#endif // MIGRATEAPPLICATIONFILESTEST_H
