@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "shareserviceurlmanager.h"
@@ -21,8 +9,8 @@
 #include "pimcommon_debug.h"
 #include <KActionMenu>
 #include <KLocalizedString>
-#include <QMenu>
 #include <QDesktopServices>
+#include <QMenu>
 #include <QUrlQuery>
 
 using namespace PimCommon;
@@ -35,8 +23,8 @@ public:
     {
     }
 
-    QIcon typeToIcon(ShareServiceUrlManager::ServiceType type) const;
-    QString typeToI18n(ShareServiceUrlManager::ServiceType type) const;
+    Q_REQUIRED_RESULT QIcon typeToIcon(ShareServiceUrlManager::ServiceType type) const;
+    Q_REQUIRED_RESULT QString typeToI18n(ShareServiceUrlManager::ServiceType type) const;
     void initializeMenu();
     KActionMenu *mMenu = nullptr;
     ShareServiceUrlManager *const q;
@@ -46,8 +34,8 @@ void ShareServiceUrlManagerPrivate::initializeMenu()
 {
     mMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("document-share")), i18n("Share On..."), q);
     for (int i = 0; i < ShareServiceUrlManager::ServiceEndType; ++i) {
-        const ShareServiceUrlManager::ServiceType type = static_cast<ShareServiceUrlManager::ServiceType>(i);
-        QAction *action = new QAction(i18nc("@action:inmenu Share On...", "%1", typeToI18n(type)), q);
+        const auto type = static_cast<ShareServiceUrlManager::ServiceType>(i);
+        auto action = new QAction(i18nc("@action:inmenu Share On...", "%1", typeToI18n(type)), q);
         action->setData(QVariant::fromValue(type));
         const QIcon icon = typeToIcon(type);
         if (!icon.isNull()) {
@@ -80,7 +68,7 @@ QIcon ShareServiceUrlManagerPrivate::typeToIcon(ShareServiceUrlManager::ServiceT
     case ShareServiceUrlManager::LiveJournal:
         break;
     case ShareServiceUrlManager::ServiceEndType:
-        qCWarning(PIMCOMMON_LOG) << "icon for unknow type requested. It's a bug.";
+        qCWarning(PIMCOMMON_LOG) << "icon for unknown type requested. It's a bug.";
         break;
     }
 
@@ -113,7 +101,7 @@ QString ShareServiceUrlManagerPrivate::typeToI18n(ShareServiceUrlManager::Servic
         str = i18n("LiveJournal");
         break;
     case ShareServiceUrlManager::ServiceEndType:
-        qCWarning(PIMCOMMON_LOG) << "text for unknow type requested. It's a bug.";
+        qCWarning(PIMCOMMON_LOG) << "text for unknown type requested. It's a bug.";
         break;
     }
     return str;
@@ -126,10 +114,7 @@ ShareServiceUrlManager::ShareServiceUrlManager(QObject *parent)
     d->initializeMenu();
 }
 
-ShareServiceUrlManager::~ShareServiceUrlManager()
-{
-    delete d;
-}
+ShareServiceUrlManager::~ShareServiceUrlManager() = default;
 
 KActionMenu *ShareServiceUrlManager::menu() const
 {
@@ -139,7 +124,7 @@ KActionMenu *ShareServiceUrlManager::menu() const
 void ShareServiceUrlManager::slotSelectServiceUrl(QAction *act)
 {
     if (act) {
-        const ServiceType type = act->data().value<PimCommon::ShareServiceUrlManager::ServiceType>();
+        const auto type = act->data().value<PimCommon::ShareServiceUrlManager::ServiceType>();
         Q_EMIT serviceUrlSelected(type);
     }
 }
@@ -151,8 +136,7 @@ QUrl ShareServiceUrlManager::generateServiceUrl(const QString &link, const QStri
         return url;
     }
     switch (type) {
-    case Fbook:
-    {
+    case Fbook: {
         url.setUrl(QStringLiteral("https://www.facebook.com/sharer.php"));
         QUrlQuery urlQuery;
         urlQuery.addQueryItem(QStringLiteral("u"), link);
@@ -160,8 +144,7 @@ QUrl ShareServiceUrlManager::generateServiceUrl(const QString &link, const QStri
         url.setQuery(urlQuery);
         break;
     }
-    case Twitter:
-    {
+    case Twitter: {
         url.setUrl(QStringLiteral("https://twitter.com/share"));
         QUrlQuery urlQuery;
         urlQuery.addQueryItem(QStringLiteral("url"), link);
@@ -169,8 +152,7 @@ QUrl ShareServiceUrlManager::generateServiceUrl(const QString &link, const QStri
         url.setQuery(urlQuery);
         break;
     }
-    case MailTo:
-    {
+    case MailTo: {
         url.setUrl(QStringLiteral("mailto:"));
         QUrlQuery urlQuery;
         urlQuery.addQueryItem(QStringLiteral("subject"), title);
@@ -178,8 +160,7 @@ QUrl ShareServiceUrlManager::generateServiceUrl(const QString &link, const QStri
         url.setQuery(urlQuery);
         break;
     }
-    case LinkedIn:
-    {
+    case LinkedIn: {
         url.setUrl(QStringLiteral("http://www.linkedin.com/shareArticle"));
         QUrlQuery urlQuery;
         urlQuery.addQueryItem(QStringLiteral("mini"), QStringLiteral("true"));
@@ -188,8 +169,7 @@ QUrl ShareServiceUrlManager::generateServiceUrl(const QString &link, const QStri
         url.setQuery(urlQuery);
         break;
     }
-    case Evernote:
-    {
+    case Evernote: {
         url.setUrl(QStringLiteral("https://www.evernote.com/clip.action"));
         QUrlQuery urlQuery;
         urlQuery.addQueryItem(QStringLiteral("url"), link);
@@ -197,8 +177,7 @@ QUrl ShareServiceUrlManager::generateServiceUrl(const QString &link, const QStri
         url.setQuery(urlQuery);
         break;
     }
-    case Pocket:
-    {
+    case Pocket: {
         url.setUrl(QStringLiteral("https://getpocket.com/save"));
         QUrlQuery urlQuery;
         urlQuery.addQueryItem(QStringLiteral("url"), link);
@@ -206,8 +185,7 @@ QUrl ShareServiceUrlManager::generateServiceUrl(const QString &link, const QStri
         url.setQuery(urlQuery);
         break;
     }
-    case LiveJournal:
-    {
+    case LiveJournal: {
         url.setUrl(QStringLiteral("http://www.livejournal.com/update.bml"));
         QUrlQuery urlQuery;
         urlQuery.addQueryItem(QStringLiteral("event"), link);
