@@ -1,46 +1,34 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "templatelistwidget.h"
 #include "templateeditdialog.h"
 
-#include <KConfigGroup>
-#include <KSharedConfig>
-#include <KMessageBox>
-#include <KLocalizedString>
-#include <QMenu>
-#include <KNS3/DownloadDialog>
 #include <KAuthorized>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KNewStuff3/KNS3/QtQuickDialogWrapper>
+#include <KSharedConfig>
 #include <QIcon>
+#include <QMenu>
 
-#include <QListWidgetItem>
-#include <QPointer>
-#include <QMimeData>
 #include <QDropEvent>
 #include <QFileDialog>
+#include <QListWidgetItem>
+#include <QMimeData>
+#include <QPointer>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class TemplateListWidgetPrivate
 {
 public:
     TemplateListWidgetPrivate(const QString &configName, TemplateListWidget *qq)
-        : dirty(false)
-        , config(KSharedConfig::openConfig(configName, KConfig::NoGlobals))
+        : config(KSharedConfig::openConfig(configName, KConfig::NoGlobals))
         , q(qq)
     {
     }
@@ -52,7 +40,7 @@ public:
 
     void createListWidgetItem(const QString &name, const QString &text, bool isDefaultTemplate)
     {
-        QListWidgetItem *item = new QListWidgetItem(name, q);
+        auto item = new QListWidgetItem(name, q);
         item->setData(TemplateListWidget::Text, text);
         item->setData(TemplateListWidget::DefaultTemplate, isDefaultTemplate);
         if (isDefaultTemplate) {
@@ -83,7 +71,12 @@ public:
 
     void slotRemove()
     {
-        if (KMessageBox::Yes == KMessageBox::questionYesNo(q, i18n("Do you want to delete selected template?"), i18n("Delete template"))) {
+        const int answer = KMessageBox::questionYesNo(q,
+                                                      i18n("Do you want to delete selected template?"),
+                                                      i18n("Delete template"),
+                                                      KStandardGuiItem::del(),
+                                                      KStandardGuiItem::cancel());
+        if (answer == KMessageBox::Yes) {
             const QList<QListWidgetItem *> lstSelectedItems = q->selectedItems();
             for (QListWidgetItem *item : lstSelectedItems) {
                 if (item->data(TemplateListWidget::DefaultTemplate).toBool() == false) {
@@ -167,51 +160,51 @@ public:
     {
         const QList<QListWidgetItem *> lstSelectedItems = q->selectedItems();
         const bool listSelectedIsEmpty = lstSelectedItems.isEmpty();
-        QMenu *menu = new QMenu(q);
+        auto menu = new QMenu(q);
 
         if (!listSelectedIsEmpty) {
             menu->addAction(i18n("Insert template"), q, [this]() {
-                    slotInsertTemplate();
-                });
+                slotInsertTemplate();
+            });
             menu->addSeparator();
         }
 
         menu->addAction(i18n("Add..."), q, [this]() {
-                slotAdd();
-            });
+            slotAdd();
+        });
         if (!listSelectedIsEmpty) {
             const bool defaultTemplate = lstSelectedItems.first()->data(TemplateListWidget::DefaultTemplate).toBool();
             if (lstSelectedItems.count() == 1) {
                 menu->addAction(defaultTemplate ? i18n("Show...") : i18n("Modify..."), q, [this]() {
-                        slotModify();
-                    });
-                menu->addAction(i18n("Duplicate"), q, [this]() {
-                        slotDuplicate();
-                    });
+                    slotModify();
+                });
+                menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")),
+                                i18n("Duplicate"), q,
+                                [this]() { slotDuplicate(); });
             }
             if (lstSelectedItems.count() == 1 && !defaultTemplate) {
                 menu->addSeparator();
                 menu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove"), q, [this]() {
-                        slotRemove();
-                    });
+                    slotRemove();
+                });
             }
         }
         menu->addSeparator();
         if (q->count() > 0) {
             menu->addAction(i18n("Export..."), q, [this]() {
-                    slotExportTemplates();
-                });
+                slotExportTemplates();
+            });
         }
         menu->addAction(i18n("Import..."), q, [this]() {
-                slotImportTemplates();
-            });
+            slotImportTemplates();
+        });
 
         if (KAuthorized::authorize(QStringLiteral("ghns"))) {
             if (!knewstuffConfigName.isEmpty()) {
                 menu->addSeparator();
                 menu->addAction(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")), i18n("Download new Templates..."), q, [this]() {
-                        slotDownloadTemplates();
-                    });
+                    slotDownloadTemplates();
+                });
             }
         }
 
@@ -274,9 +267,7 @@ public:
 
     void slotDownloadTemplates()
     {
-        QPointer<KNS3::DownloadDialog> downloadThemesDialog = new KNS3::DownloadDialog(knewstuffConfigName);
-        downloadThemesDialog->exec();
-        delete downloadThemesDialog;
+        KNS3::QtQuickDialogWrapper(knewstuffConfigName).exec();
     }
 
     void save()
@@ -290,9 +281,9 @@ public:
     }
 
     QString knewstuffConfigName;
-    bool dirty;
+    bool dirty = false;
     KSharedConfig::Ptr config;
-    TemplateListWidget *q;
+    TemplateListWidget *const q;
 };
 
 TemplateListWidget::TemplateListWidget(const QString &configName, QWidget *parent)
@@ -303,20 +294,17 @@ TemplateListWidget::TemplateListWidget(const QString &configName, QWidget *paren
     setDragDropMode(QAbstractItemView::DragDrop);
 
     connect(this, &TemplateListWidget::customContextMenuRequested, this, [this](QPoint p) {
-            d->slotContextMenu(p);
-        });
+        d->slotContextMenu(p);
+    });
     connect(this, &TemplateListWidget::doubleClicked, this, [this]() {
-            d->slotModify();
-        });
+        d->slotModify();
+    });
     connect(this, &TemplateListWidget::insertNewTemplate, this, [this](const QString &tmp) {
-            d->slotInsertNewTemplate(tmp);
-        });
+        d->slotInsertNewTemplate(tmp);
+    });
 }
 
-TemplateListWidget::~TemplateListWidget()
-{
-    delete d;
-}
+TemplateListWidget::~TemplateListWidget() = default;
 
 void TemplateListWidget::loadTemplates()
 {
@@ -330,18 +318,20 @@ QVector<defaultTemplate> TemplateListWidget::defaultTemplates()
 
 QStringList TemplateListWidget::mimeTypes() const
 {
-    const QStringList lst{
-        QStringLiteral("text/plain")
-    };
+    const QStringList lst{QStringLiteral("text/plain")};
     return lst;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 QMimeData *TemplateListWidget::mimeData(const QList<QListWidgetItem *> items) const
+#else
+QMimeData *TemplateListWidget::mimeData(const QList<QListWidgetItem *> &items) const
+#endif
 {
     if (items.isEmpty()) {
         return nullptr;
     }
-    QMimeData *mimeData = new QMimeData();
+    auto mimeData = new QMimeData();
     QListWidgetItem *item = items.first();
     mimeData->setText(item->data(TemplateListWidget::Text).toString());
     return mimeData;
