@@ -1,52 +1,41 @@
 /*
 
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "translatorwidget.h"
-#include "translatorutil.h"
 #include "googletranslator.h"
-#include <KPIMTextEdit/PlainTextEditorWidget>
-#include <PimCommon/NetworkManager>
+#include "translatorutil.h"
 #include <KBusyIndicatorWidget>
+#include <PimCommon/NetworkManager>
 
-#include <QPushButton>
-#include <KLocalizedString>
-#include <kio/job.h>
 #include <KConfigGroup>
-#include <KSeparator>
+#include <KLocalizedString>
 #include <KMessageBox>
+#include <KSeparator>
+#include <QPushButton>
 
-#include <QMimeData>
-#include <QIcon>
+#include <KSharedConfig>
 #include <QComboBox>
 #include <QHBoxLayout>
-#include <QVBoxLayout>
-#include <QLabel>
-#include <QToolButton>
+#include <QIcon>
 #include <QKeyEvent>
-#include <QShortcut>
-#include <QPainter>
-#include <QSplitter>
-#include <KSharedConfig>
+#include <QLabel>
+#include <QMimeData>
 #include <QNetworkConfigurationManager>
+#include <QPainter>
+#include <QShortcut>
+#include <QSplitter>
+#include <QToolButton>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
-
+namespace
+{
+static const char myTranslatorWidgetConfigGroupName[] = "TranslatorWidget";
+}
 class Q_DECL_HIDDEN TranslatorWidget::TranslatorWidgetPrivate
 {
 public:
@@ -62,7 +51,7 @@ public:
     void initLanguage();
     void fillToCombobox(const QString &lang);
 
-    QMap<QString, QMap<QString, QString> > listLanguage;
+    QMap<QString, QMap<QString, QString>> listLanguage;
     QByteArray data;
     TranslatorTextEdit *inputText = nullptr;
     KPIMTextEdit::PlainTextEditorWidget *translatedText = nullptr;
@@ -173,12 +162,11 @@ TranslatorWidget::~TranslatorWidget()
     disconnect(d->inputText, &TranslatorTextEdit::textChanged, this, &TranslatorWidget::slotTextChanged);
     disconnect(d->inputText, &TranslatorTextEdit::translateText, this, &TranslatorWidget::slotTranslate);
     writeConfig();
-    delete d;
 }
 
 void TranslatorWidget::writeConfig()
 {
-    KConfigGroup myGroup(KSharedConfig::openConfig(), "TranslatorWidget");
+    KConfigGroup myGroup(KSharedConfig::openConfig(), myTranslatorWidgetConfigGroupName);
     if (d->languageSettingsChanged) {
         myGroup.writeEntry(QStringLiteral("FromLanguage"), d->from->itemData(d->from->currentIndex()).toString());
         myGroup.writeEntry("ToLanguage", d->to->itemData(d->to->currentIndex()).toString());
@@ -189,7 +177,7 @@ void TranslatorWidget::writeConfig()
 
 void TranslatorWidget::readConfig()
 {
-    KConfigGroup myGroup(KSharedConfig::openConfig(), "TranslatorWidget");
+    KConfigGroup myGroup(KSharedConfig::openConfig(), myTranslatorWidgetConfigGroupName);
     const QString from = myGroup.readEntry(QStringLiteral("FromLanguage"));
     const QString to = myGroup.readEntry(QStringLiteral("ToLanguage"));
     if (from.isEmpty()) {
@@ -215,10 +203,10 @@ void TranslatorWidget::init()
     connect(d->abstractTranslator, &PimCommon::GoogleTranslator::translateDone, this, &TranslatorWidget::slotTranslateDone);
     connect(d->abstractTranslator, &PimCommon::GoogleTranslator::translateFailed, this, &TranslatorWidget::slotTranslateFailed);
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
-    QHBoxLayout *hboxLayout = new QHBoxLayout;
-    QToolButton *closeBtn = new QToolButton(this);
+    auto layout = new QVBoxLayout(this);
+    layout->setContentsMargins({});
+    auto hboxLayout = new QHBoxLayout;
+    auto closeBtn = new QToolButton(this);
     closeBtn->setObjectName(QStringLiteral("close-button"));
     closeBtn->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
     closeBtn->setIconSize(QSize(16, 16));
@@ -231,7 +219,7 @@ void TranslatorWidget::init()
     hboxLayout->addWidget(closeBtn);
     connect(closeBtn, &QToolButton::clicked, this, &TranslatorWidget::slotCloseWidget);
 
-    QLabel *label = new QLabel(i18nc("Translate from language", "From:"));
+    auto label = new QLabel(i18nc("Translate from language", "From:"));
     hboxLayout->addWidget(label);
     d->from = new QComboBox;
     d->from->setMinimumWidth(50);
@@ -246,12 +234,11 @@ void TranslatorWidget::init()
 
     hboxLayout->addWidget(d->to);
 
-    KSeparator *separator = new KSeparator;
+    auto separator = new KSeparator;
     separator->setOrientation(Qt::Vertical);
     hboxLayout->addWidget(separator);
 
-    d->invert = new QPushButton(
-        i18nc("Invert language choices so that from becomes to and to becomes from", "Invert"), this);
+    d->invert = new QPushButton(i18nc("Invert language choices so that from becomes to and to becomes from", "Invert"), this);
     d->invert->setObjectName(QStringLiteral("invert-button"));
     connect(d->invert, &QPushButton::clicked, this, &TranslatorWidget::slotInvertLanguage);
     hboxLayout->addWidget(d->invert);
@@ -274,7 +261,7 @@ void TranslatorWidget::init()
     connect(d->translate, &QPushButton::clicked, this, &TranslatorWidget::slotTranslate);
 
     if (!qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING")) {
-        QPushButton *debugButton = new QPushButton(i18n("Debug"));
+        auto debugButton = new QPushButton(i18n("Debug"));
         hboxLayout->addWidget(debugButton);
         connect(debugButton, &QPushButton::clicked, this, &TranslatorWidget::slotDebug);
     }
@@ -289,7 +276,7 @@ void TranslatorWidget::init()
     d->splitter = new QSplitter;
     d->splitter->setChildrenCollapsible(false);
     d->inputText = new TranslatorTextEdit(this);
-    KPIMTextEdit::PlainTextEditorWidget *editorWidget = new KPIMTextEdit::PlainTextEditorWidget(d->inputText);
+    auto editorWidget = new KPIMTextEdit::PlainTextEditorWidget(d->inputText);
     d->inputText->setObjectName(QStringLiteral("inputtext"));
     d->inputText->setPlaceholderText(i18n("Drag text that you want to translate. (Be careful text will be send to Google Server)."));
     connect(d->inputText, &TranslatorTextEdit::textChanged, this, &TranslatorWidget::slotTextChanged);
@@ -305,15 +292,15 @@ void TranslatorWidget::init()
     layout->addWidget(d->splitter);
 
     d->initLanguage();
-    d->from->setCurrentIndex(0);   //Fill "to" combobox
+    d->from->setCurrentIndex(0); // Fill "to" combobox
     slotFromLanguageChanged(0, true);
     slotTextChanged();
     readConfig();
-    connect(d->from, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this](int val) {
+    connect(d->from, &QComboBox::currentIndexChanged, this, [this](int val) {
         slotFromLanguageChanged(val, false);
         slotConfigChanged();
     });
-    connect(d->to, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this]() {
+    connect(d->to, &QComboBox::currentIndexChanged, this, [this]() {
         slotConfigChanged();
         slotTranslate();
     });
@@ -446,7 +433,7 @@ bool TranslatorWidget::event(QEvent *e)
     // window-global actions (e.g. Emil Sedgh binds Esc to "close tab").
     // With a shortcut override we can catch this before it gets to kactions.
     if (e->type() == QEvent::ShortcutOverride || e->type() == QEvent::KeyPress) {
-        QKeyEvent *kev = static_cast<QKeyEvent * >(e);
+        auto kev = static_cast<QKeyEvent *>(e);
         if (kev->key() == Qt::Key_Escape) {
             e->accept();
             slotCloseWidget();
