@@ -1,30 +1,18 @@
 /*
 
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TRANSLATORWIDGET_H
-#define TRANSLATORWIDGET_H
+#pragma once
 
 #include "pimcommon_export.h"
-#include "kpimtextedit/plaintexteditor.h"
-#include <kio/job.h>
-#include "kpimtextedit/plaintexteditorwidget.h"
-namespace PimCommon {
+#include <KIO/Job>
+#include <KPIMTextEdit/PlainTextEditor>
+#include <KPIMTextEdit/PlainTextEditorWidget>
+namespace PimCommon
+{
 class TranslatorResultTextEdit : public KPIMTextEdit::PlainTextEditor
 {
     Q_OBJECT
@@ -98,8 +86,7 @@ private:
     void init();
     void initLanguage();
     class TranslatorWidgetPrivate;
-    TranslatorWidgetPrivate *const d;
+    std::unique_ptr<TranslatorWidgetPrivate> const d;
 };
 }
 
-#endif /* TRANSLATORWIDGET_H */
