@@ -5,21 +5,9 @@
 
   Author: Don Sanders <sanders@kde.org>
 
-  Copyright (C) 2000 Don Sanders <sanders@kde.org>
+  SPDX-FileCopyrightText: 2000 Don Sanders <sanders@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "broadcaststatus.h"
@@ -33,7 +21,8 @@ static void deleteGlobalStaticBroadcastStatus()
     instance_ = nullptr;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 BroadcastStatus *BroadcastStatus::instance()
 {
     if (!instance_) {
@@ -62,7 +51,6 @@ BroadcastStatus::BroadcastStatus()
 BroadcastStatus::~BroadcastStatus()
 {
     instance_ = nullptr;
-    delete d;
 }
 
 void BroadcastStatus::setStatusMsg(const QString &message)
