@@ -1,46 +1,23 @@
 /*
- * Copyright (c) 2011-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- *  In addition, as a special exception, the copyright holders give
- *  permission to link the code of this program with any edition of
- *  the Qt library by Trolltech AS, Norway (or with modified versions
- *  of Qt that use the same license as Qt), and distribute linked
- *  combinations including the two.  You must obey the GNU General
- *  Public License in all respects for all of the code used other than
- *  Qt.  If you modify this file, you may extend this exception to
- *  your version of the file, but you are not obligated to do so.  If
- *  you do not wish to do so, delete this exception statement from
- *  your version.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 #include "renamefiledialog.h"
-#include <kseparator.h>
-#include <QLineEdit>
-#include <QPushButton>
-#include <KLocalizedString>
 #include <KIO/StatJob>
 #include <KJobWidgets>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KStandardGuiItem>
+#include <QLineEdit>
+#include <QPushButton>
+#include <kseparator.h>
 
-#include <QHBoxLayout>
 #include <QCheckBox>
+#include <QFileInfo>
+#include <QHBoxLayout>
 #include <QLabel>
 #include <QVBoxLayout>
-#include <QFileInfo>
 
 using namespace PimCommon;
 
@@ -53,9 +30,9 @@ public:
     {
     }
 
-    QString suggestName(const QUrl &baseURL, const QString &oldName);
+    Q_REQUIRED_RESULT QString suggestName(const QUrl &baseURL, const QString &oldName);
 
-    QUrl url;
+    const QUrl url;
     QCheckBox *applyAll = nullptr;
     QPushButton *renameBtn = nullptr;
     QPushButton *suggestNewNameBtn = nullptr;
@@ -65,11 +42,12 @@ public:
 
 QString PimCommon::RenameFileDialog::RenameFileDialogPrivate::suggestName(const QUrl &baseURL, const QString &oldName)
 {
-    QString dotSuffix, suggestedName;
+    QString dotSuffix;
+    QString suggestedName;
     QString basename = oldName;
     const QChar spacer(QLatin1Char(' '));
 
-    //ignore dots at the beginning, that way "..aFile.tar.gz" will become "..aFile 1.tar.gz" instead of " 1..aFile.tar.gz"
+    // ignore dots at the beginning, that way "..aFile.tar.gz" will become "..aFile 1.tar.gz" instead of " 1..aFile.tar.gz"
     int index = basename.indexOf(QLatin1Char('.'));
     int continuous = 0;
     while (continuous == index) {
@@ -89,7 +67,7 @@ QString PimCommon::RenameFileDialog::RenameFileDialogPrivate::suggestName(const
         bool ok;
         const int number = tmp.toInt(&ok);
 
-        if (!ok) {  // ok there is no number
+        if (!ok) { // ok there is no number
             suggestedName = basename + spacer + QLatin1Char('1') + dotSuffix;
         } else {
             // yes there's already a number behind the spacer so increment it by one
@@ -120,12 +98,12 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     , d(new RenameFileDialogPrivate(url, this))
 {
     setWindowTitle(i18nc("@title:window", "File Already Exists"));
-    QVBoxLayout *pLayout = new QVBoxLayout(this);
+    auto pLayout = new QVBoxLayout(this);
 
-    QLabel *label = new QLabel(xi18n("A file named <filename>%1</filename> already exists. Do you want to overwrite it?", url.fileName()), this);
+    auto label = new QLabel(xi18n("A file named <filename>%1</filename> already exists. Do you want to overwrite it?", url.fileName()), this);
     pLayout->addWidget(label);
 
-    QHBoxLayout *renameLayout = new QHBoxLayout();
+    auto renameLayout = new QHBoxLayout();
     pLayout->addLayout(renameLayout);
 
     d->nameEdit = new QLineEdit(this);
@@ -136,20 +114,20 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     renameLayout->addWidget(d->suggestNewNameBtn);
     connect(d->suggestNewNameBtn, &QPushButton::clicked, this, &RenameFileDialog::slotSuggestNewNamePressed);
 
-    QPushButton *overWrite = new QPushButton(this);
+    auto overWrite = new QPushButton(this);
     KStandardGuiItem::assign(overWrite, KStandardGuiItem::Overwrite);
     connect(overWrite, &QPushButton::clicked, this, &RenameFileDialog::slotOverwritePressed);
 
-    QPushButton *ignore = new QPushButton(i18n("&Ignore"), this);
+    auto ignore = new QPushButton(i18n("&Ignore"), this);
     connect(ignore, &QPushButton::clicked, this, &RenameFileDialog::slotIgnorePressed);
 
     d->renameBtn = new QPushButton(i18n("&Rename"), this);
     connect(d->renameBtn, &QPushButton::clicked, this, &RenameFileDialog::slotRenamePressed);
 
-    KSeparator *separator = new KSeparator(this);
+    auto separator = new KSeparator(this);
     pLayout->addWidget(separator);
 
-    QHBoxLayout *layout = new QHBoxLayout();
+    auto layout = new QHBoxLayout();
     pLayout->addLayout(layout);
 
     if (multiFiles) {
@@ -163,10 +141,7 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     layout->addWidget(ignore);
 }
 
-RenameFileDialog::~RenameFileDialog()
-{
-    delete d;
-}
+RenameFileDialog::~RenameFileDialog() = default;
 
 void RenameFileDialog::slotOverwritePressed()
 {
