@@ -5,8 +5,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef PIMCOMMON_ACLENTRYDIALOG_P_H
-#define PIMCOMMON_ACLENTRYDIALOG_P_H
+#pragma once
 
 #include <KIMAP/Acl>
 
@@ -56,11 +55,10 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    class AclEntryDialogPrivate;
+    std::unique_ptr<AclEntryDialogPrivate> const d;
 
     //@endcond
 };
 }
 
-#endif
