@@ -1,29 +1,18 @@
 /*
- * Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
- * Copyright (c) 2010 Tobias Koenig <tokoe@kdab.com>
+ * SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+ * SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kdab.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef PIMCOMMON_ACLUTILS_P_H
-#define PIMCOMMON_ACLUTILS_P_H
+#pragma once
 
 #include <KIMAP/Acl>
 
-namespace PimCommon {
-namespace AclUtils {
+namespace PimCommon
+{
+namespace AclUtils
+{
 /**
  * Returns the number of standard permissions available.
  */
@@ -58,4 +47,3 @@ QString guessUserName(const QString &loginName, const QString &serverName);
 }
 }
 
-#endif
