@@ -1,71 +1,59 @@
 /*
   This file is part of libkdepim.
 
-  Copyright (c) 2002 Helge Deller <deller@gmx.de>
-  Copyright (c) 2002 Lubos Lunak <llunak@suse.cz>
-  Copyright (c) 2001,2003 Carsten Pfeiffer <pfeiffer@kde.org>
-  Copyright (c) 2001 Waldo Bastian <bastian@kde.org>
-  Copyright (c) 2004 Daniel Molkentin <danimo@klaralvdalens-datakonsult.se>
-  Copyright (c) 2004 Karl-Heinz Zimmer <khz@klaralvdalens-datakonsult.se>
-  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2002 Helge Deller <deller@gmx.de>
+  SPDX-FileCopyrightText: 2002 Lubos Lunak <llunak@suse.cz>
+  SPDX-FileCopyrightText: 2001, 2003 Carsten Pfeiffer <pfeiffer@kde.org>
+  SPDX-FileCopyrightText: 2001 Waldo Bastian <bastian@kde.org>
+  SPDX-FileCopyrightText: 2004 Daniel Molkentin <danimo@klaralvdalens-datakonsult.se>
+  SPDX-FileCopyrightText: 2004 Karl-Heinz Zimmer <khz@klaralvdalens-datakonsult.se>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "addresseelineedit.h"
 #include "addresseelineedit_p.h"
-#include "addresseelineeditutil.h"
 #include "addresseelineeditmanager.h"
+#include "addresseelineeditutil.h"
 #include "addressline/recentaddress/recentaddresses.h"
 #include <KLDAP/LdapClientSearch>
 
 #include <KContacts/VCardConverter>
+#include <kcontacts_version.h>
 
-#include <Job>
-#include <QUrl>
+#include <Akonadi/Job>
 #include <KConfigGroup>
+#include <QUrl>
 
-#include <KEmailAddress>
-#include <KColorScheme>
-#include <KJobWidgets>
-#include <kcontacts/contactgrouptool.h>
-#include <KIO/StoredTransferJob>
 #include <Akonadi/Contact/ContactGroupExpandJob>
 #include <Akonadi/Contact/ContactGroupSearchJob>
+#include <KColorScheme>
+#include <KContacts/ContactGroupTool>
+#include <KEmailAddress>
+#include <KIO/StoredTransferJob>
+#include <KJobWidgets>
 
-#include <KCompletionBox>
 #include "pimcommonakonadi_debug.h"
+#include <KCodecs>
+#include <KCompletionBox>
 #include <KLocalizedString>
 #include <KStandardShortcut>
-#include <KCodecs>
 
-#include <QMimeData>
-#include <QApplication>
-#include <QObject>
-#include <QBuffer>
-#include <QEvent>
-#include <QClipboard>
-#include <QKeyEvent>
-#include <QDropEvent>
-#include <QMouseEvent>
-#include <QMenu>
-#include <KSharedConfig>
-#include <KMessageBox>
 #include <ContactGroupExpandJob>
-#include <kcontacts/vcarddrag.h>
+#include <KContacts/VCardDrag>
+#include <KMessageBox>
+#include <KSharedConfig>
+#include <QApplication>
+#include <QBuffer>
+#include <QClipboard>
+#include <QDropEvent>
+#include <QEvent>
+#include <QKeyEvent>
+#include <QMenu>
+#include <QMimeData>
+#include <QMouseEvent>
+#include <QObject>
 #include <addressline/completionconfiguredialog/completionconfiguredialog.h>
 
 using namespace PimCommon;
@@ -170,7 +158,7 @@ void AddresseeLineEdit::keyPressEvent(QKeyEvent *event)
     const int key = event->key() | event->modifiers();
 
     if (KStandardShortcut::shortcut(KStandardShortcut::SubstringCompletion).contains(key)) {
-        //TODO: add LDAP substring lookup, when it becomes available in KPIM::LDAPSearch
+        // TODO: add LDAP substring lookup, when it becomes available in KPIM::LDAPSearch
         d->updateSearchString();
         d->startSearches();
         d->doCompletion(true);
@@ -178,7 +166,7 @@ void AddresseeLineEdit::keyPressEvent(QKeyEvent *event)
     } else if (KStandardShortcut::shortcut(KStandardShortcut::TextCompletion).contains(key)) {
         const int len = text().length();
 
-        if (len == cursorPosition()) {   // at End?
+        if (len == cursorPosition()) { // at End?
             d->updateSearchString();
             d->startSearches();
             d->doCompletion(true);
@@ -201,7 +189,7 @@ void AddresseeLineEdit::keyPressEvent(QKeyEvent *event)
         d->updateSearchString();
 
         QString searchString(d->searchString());
-        //LDAP does not know about our string manipulation, remove it
+        // LDAP does not know about our string manipulation, remove it
         if (d->searchExtended()) {
             searchString = d->searchString().mid(1);
         }
@@ -276,10 +264,7 @@ void AddresseeLineEdit::mouseReleaseEvent(QMouseEvent *event)
 {
     // reimplemented from QLineEdit::mouseReleaseEvent()
 #ifndef QT_NO_CLIPBOARD
-    if (d->useCompletion()
-        && QApplication::clipboard()->supportsSelection()
-        && !isReadOnly()
-        && event->button() == Qt::MiddleButton) {
+    if (d->useCompletion() && QApplication::clipboard()->supportsSelection() && !isReadOnly() && event->button() == Qt::MiddleButton) {
         d->setSmartPaste(true);
     }
 #endif
@@ -298,9 +283,8 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
         KContacts::Addressee::List list;
         KContacts::VCardDrag::fromMimeData(md, list);
 
-        const KContacts::Addressee::List::ConstIterator end(list.constEnd());
-        for (KContacts::Addressee::List::ConstIterator ait = list.constBegin(); ait != end; ++ait) {
-            insertEmails((*ait).emails());
+        for (const KContacts::Addressee &addr : std::as_const(list)) {
+            insertEmails(addr.emails());
         }
     }
     // Case two: The user dropped a list or Urls.
@@ -315,7 +299,13 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
             // email-address.
             if (url.scheme() == QLatin1String("mailto")) {
                 KContacts::Addressee addressee;
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
                 addressee.insertEmail(KEmailAddress::decodeMailtoUrl(url), true /* preferred */);
+#else
+                KContacts::Email email(KEmailAddress::decodeMailtoUrl(url));
+                email.setPreferred(true);
+                addressee.addEmail(email);
+#endif
                 list += addressee;
             } else { // Otherwise, download the vCard to which the Url points
                 KContacts::VCardConverter converter;
@@ -325,13 +315,13 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
                     QByteArray data = job->data();
                     list += converter.parseVCards(data);
 
-                    if (list.isEmpty()) {  // try to parse a contact group
+                    if (list.isEmpty()) { // try to parse a contact group
                         KContacts::ContactGroup group;
                         QBuffer dataStream(&data);
                         dataStream.open(QIODevice::ReadOnly);
                         QString error;
                         if (KContacts::ContactGroupTool::convertFromXml(&dataStream, group, &error)) {
-                            Akonadi::ContactGroupExpandJob *expandJob = new Akonadi::ContactGroupExpandJob(group);
+                            auto expandJob = new Akonadi::ContactGroupExpandJob(group);
                             connect(expandJob, &Akonadi::ContactGroupExpandJob::result, this, &AddresseeLineEdit::groupExpandResult);
                             expandJob->start();
                         } else {
@@ -347,7 +337,7 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
         }
 
         // Now, let the user choose which addressee to add.
-        for (const KContacts::Addressee &addressee : qAsConst(list)) {
+        for (const KContacts::Addressee &addressee : std::as_const(list)) {
             insertEmails(addressee.emails());
         }
     }
@@ -397,7 +387,13 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
                             QUrl url(dropData);
                             if (url.scheme() == QLatin1String("mailto")) {
                                 KContacts::Addressee addressee;
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
                                 addressee.insertEmail(KEmailAddress::decodeMailtoUrl(url), true /* preferred */);
+#else
+                                KContacts::Email email(KEmailAddress::decodeMailtoUrl(url));
+                                email.setPreferred(true);
+                                addressee.addEmail(email);
+#endif
                                 insertEmails(addressee.emails());
                             } else {
                                 setText(KEmailAddress::normalizeAddressesAndDecodeIdn(dropData));
@@ -425,7 +421,7 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
 
 void AddresseeLineEdit::groupExpandResult(KJob *job)
 {
-    Akonadi::ContactGroupExpandJob *expandJob = qobject_cast<Akonadi::ContactGroupExpandJob *>(job);
+    auto expandJob = qobject_cast<Akonadi::ContactGroupExpandJob *>(job);
 
     if (!expandJob) {
         return;
@@ -458,12 +454,12 @@ void AddresseeLineEdit::insertEmails(const QStringList &emails)
         setText(contents + emails.front());
         return;
     }
-    //multiple emails, let the user choose one
+    // multiple emails, let the user choose one
     QMenu menu(this);
     menu.setTitle(i18n("Select email from contact"));
     menu.setObjectName(QStringLiteral("Addresschooser"));
-    for (QStringList::const_iterator it = emails.constBegin(), end = emails.constEnd(); it != end; ++it) {
-        menu.addAction(*it);
+    for (const QString &email : emails) {
+        menu.addAction(email);
     }
     const QAction *result = menu.exec(QCursor::pos());
     if (!result) {
@@ -489,7 +485,7 @@ bool AddresseeLineEdit::isCompletionEnabled() const
 
 void AddresseeLineEdit::addItem(const Akonadi::Item &item, int weight, int source)
 {
-    //Let Akonadi results always have a higher weight than baloo results
+    // Let Akonadi results always have a higher weight than baloo results
     if (item.hasPayload<KContacts::Addressee>()) {
         addContact(item.payload<KContacts::Addressee>(), weight + 1, source);
     } else if (item.hasPayload<KContacts::ContactGroup>()) {
@@ -504,9 +500,9 @@ void AddresseeLineEdit::addContactGroup(const KContacts::ContactGroup &group, in
 
 void AddresseeLineEdit::addContact(const QStringList &emails, const KContacts::Addressee &addr, int weight, int source, QString append)
 {
-    int isPrefEmail = 1; //first in list is preferredEmail
+    int isPrefEmail = 1; // first in list is preferredEmail
     for (const QString &email : emails) {
-        //TODO: highlight preferredEmail
+        // TODO: highlight preferredEmail
         const QString givenName = addr.givenName();
         const QString familyName = addr.familyName();
         const QString nickName = addr.nickName();
@@ -551,7 +547,7 @@ void AddresseeLineEdit::addContact(const QStringList &emails, const KContacts::A
     }
 }
 
-void AddresseeLineEdit::addContact(const KContacts::Addressee &addr, int weight, int source, QString append)
+void AddresseeLineEdit::addContact(const KContacts::Addressee &addr, int weight, int source, const QString &append)
 {
     const QStringList emails = AddresseeLineEditManager::self()->cleanupEmailList(addr.emails());
     if (emails.isEmpty()) {
@@ -564,7 +560,7 @@ void AddresseeLineEdit::addContact(const KContacts::Addressee &addr, int weight,
 void AddresseeLineEdit::contextMenuEvent(QContextMenuEvent *event)
 {
     QMenu *menu = createStandardContextMenu();
-    if (menu) {   // can be 0 on platforms with only a touch interface
+    if (menu) { // can be 0 on platforms with only a touch interface
         menu->exec(event->globalPos());
         delete menu;
     }
@@ -581,7 +577,7 @@ QMenu *AddresseeLineEdit::createStandardContextMenu()
         return nullptr;
     }
     if (d->useCompletion()) {
-        QAction *showOU = new QAction(i18n("Show Organization Unit for LDAP results"), menu);
+        auto showOU = new QAction(i18n("Show Organization Unit for LDAP results"), menu);
         showOU->setCheckable(true);
         showOU->setChecked(d->showOU());
         connect(showOU, &QAction::triggered, d, &AddresseeLineEditPrivate::slotShowOUChanged);
@@ -636,9 +632,10 @@ void AddresseeLineEdit::loadContacts()
 {
     const QString recentAddressGroupName = i18n("Recent Addresses");
     if (showRecentAddresses()) {
-        const QStringList recent
-            = AddresseeLineEditManager::self()->cleanupRecentAddressEmailList(PimCommon::RecentAddresses::self(recentAddressConfig())->addresses());
-        QString name, email;
+        const QStringList recent =
+            AddresseeLineEditManager::self()->cleanupRecentAddressEmailList(PimCommon::RecentAddresses::self(recentAddressConfig())->addresses());
+        QString name;
+        QString emailString;
 
         KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kpimcompletionorder"));
         KConfigGroup group(config, "CompletionWeights");
@@ -648,8 +645,8 @@ void AddresseeLineEdit::loadContacts()
 
         for (const QString &recentAdr : recent) {
             KContacts::Addressee addr;
-            KEmailAddress::extractEmailAddressAndName(recentAdr, email, name);
-            if (email.isEmpty()) {
+            KEmailAddress::extractEmailAddressAndName(recentAdr, emailString, name);
+            if (emailString.isEmpty()) {
                 continue;
             }
             name = KEmailAddress::quoteNameIfNecessary(name);
@@ -658,8 +655,14 @@ void AddresseeLineEdit::loadContacts()
                 name.chop(1);
             }
             addr.setNameFromString(name);
-            addr.insertEmail(email, true);
-            addContact({email}, addr, weight, idx);
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
+            addr.insertEmail(emailString, true);
+#else
+            KContacts::Email email(emailString);
+            email.setPreferred(true);
+            addr.addEmail(email);
+#endif
+            addContact({emailString}, addr, weight, idx);
         }
     } else {
         removeCompletionSource(recentAddressGroupName);
@@ -678,12 +681,8 @@ int AddresseeLineEdit::addCompletionSource(const QString &source, int weight)
 
 bool AddresseeLineEdit::eventFilter(QObject *object, QEvent *event)
 {
-    if (d->completionInitialized()
-        && (object == completionBox()
-            || completionBox()->findChild<QWidget *>(object->objectName()) == object)) {
-        if (event->type() == QEvent::MouseButtonPress
-            || event->type() == QEvent::MouseMove
-            || event->type() == QEvent::MouseButtonRelease
+    if (d->completionInitialized() && (object == completionBox() || completionBox()->findChild<QWidget *>(object->objectName()) == object)) {
+        if (event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseMove || event->type() == QEvent::MouseButtonRelease
             || event->type() == QEvent::MouseButtonDblClick) {
             const QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
             // find list box item at the event position
@@ -697,10 +696,8 @@ bool AddresseeLineEdit::eventFilter(QObject *object, QEvent *event)
             // avoid selection of headers on button press, or move or release while
             // a button is pressed
             const Qt::MouseButtons buttons = mouseEvent->buttons();
-            if (event->type() == QEvent::MouseButtonPress
-                || event->type() == QEvent::MouseButtonDblClick
-                || buttons & Qt::LeftButton || buttons & Qt::MiddleButton
-                || buttons & Qt::RightButton) {
+            if (event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonDblClick || buttons & Qt::LeftButton
+                || buttons & Qt::MiddleButton || buttons & Qt::RightButton) {
                 if (itemIsHeader(item)) {
                     return true; // eat the event, we don't want anything to happen
                 } else {
@@ -717,26 +714,22 @@ bool AddresseeLineEdit::eventFilter(QObject *object, QEvent *event)
         }
     }
 
-    if ((object == this)
-        && (event->type() == QEvent::ShortcutOverride)) {
-        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
-        if (keyEvent->key() == Qt::Key_Up || keyEvent->key() == Qt::Key_Down
-            || keyEvent->key() == Qt::Key_Tab) {
+    if ((object == this) && (event->type() == QEvent::ShortcutOverride)) {
+        auto keyEvent = static_cast<QKeyEvent *>(event);
+        if (keyEvent->key() == Qt::Key_Up || keyEvent->key() == Qt::Key_Down || keyEvent->key() == Qt::Key_Tab) {
             keyEvent->accept();
             return true;
         }
     }
 
-    if ((object == this)
-        && (event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease)
-        && completionBox()->isVisible()) {
+    if ((object == this) && (event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease) && completionBox()->isVisible()) {
         const QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
         int currentIndex = completionBox()->currentRow();
         if (currentIndex < 0) {
             return true;
         }
         if (keyEvent->key() == Qt::Key_Up) {
-            //qCDebug(PIMCOMMONAKONADI_LOG) <<"EVENTFILTER: Qt::Key_Up currentIndex=" << currentIndex;
+            // qCDebug(PIMCOMMONAKONADI_LOG) <<"EVENTFILTER: Qt::Key_Up currentIndex=" << currentIndex;
             // figure out if the item we would be moving to is one we want
             // to ignore. If so, go one further
             const QListWidgetItem *itemAbove = completionBox()->item(currentIndex);
@@ -744,7 +737,7 @@ bool AddresseeLineEdit::eventFilter(QObject *object, QEvent *event)
                 // there is a header above is, check if there is even further up
                 // and if so go one up, so it'll be selected
                 if (currentIndex > 0 && completionBox()->item(currentIndex - 1)) {
-                    //qCDebug(PIMCOMMONAKONADI_LOG) <<"EVENTFILTER: Qt::Key_Up -> skipping" << currentIndex - 1;
+                    // qCDebug(PIMCOMMONAKONADI_LOG) <<"EVENTFILTER: Qt::Key_Up -> skipping" << currentIndex - 1;
                     completionBox()->setCurrentRow(currentIndex - 1);
                     completionBox()->item(currentIndex - 1)->setSelected(true);
                 } else if (currentIndex == 0) {
@@ -766,11 +759,11 @@ bool AddresseeLineEdit::eventFilter(QObject *object, QEvent *event)
             }
         } else if (keyEvent->key() == Qt::Key_Down) {
             // same strategy for downwards
-            //qCDebug(PIMCOMMONAKONADI_LOG) <<"EVENTFILTER: Qt::Key_Down. currentIndex=" << currentIndex;
+            // qCDebug(PIMCOMMONAKONADI_LOG) <<"EVENTFILTER: Qt::Key_Down. currentIndex=" << currentIndex;
             const QListWidgetItem *itemBelow = completionBox()->item(currentIndex);
             if (itemBelow && itemIsHeader(itemBelow)) {
                 if (completionBox()->item(currentIndex + 1)) {
-                    //qCDebug(PIMCOMMONAKONADI_LOG) <<"EVENTFILTER: Qt::Key_Down -> skipping" << currentIndex+1;
+                    // qCDebug(PIMCOMMONAKONADI_LOG) <<"EVENTFILTER: Qt::Key_Down -> skipping" << currentIndex+1;
                     completionBox()->setCurrentRow(currentIndex + 1);
                     completionBox()->item(currentIndex + 1)->setSelected(true);
                 } else {
@@ -792,8 +785,7 @@ bool AddresseeLineEdit::eventFilter(QObject *object, QEvent *event)
                 completionBox()->setCurrentItem(item);
                 item->setSelected(true);
             }
-        } else if (event->type() == QEvent::KeyRelease
-                   && (keyEvent->key() == Qt::Key_Tab || keyEvent->key() == Qt::Key_Backtab)) {
+        } else if (event->type() == QEvent::KeyRelease && (keyEvent->key() == Qt::Key_Tab || keyEvent->key() == Qt::Key_Backtab)) {
             /// first, find the header of the current section
             QListWidgetItem *myHeader = nullptr;
             int myHeaderIndex = -1;
@@ -808,7 +800,7 @@ bool AddresseeLineEdit::eventFilter(QObject *object, QEvent *event)
 
                 index--;
             }
-            Q_ASSERT(myHeader);   // we should always be able to find a header
+            Q_ASSERT(myHeader); // we should always be able to find a header
 
             // find the next header (searching backwards, for Qt::Key_Backtab)
             QListWidgetItem *nextHeader = nullptr;
@@ -902,7 +894,7 @@ void AddresseeLineEdit::slotEditingFinished()
     if (!text().trimmed().isEmpty() && enableAkonadiSearch()) {
         const QStringList addresses = KEmailAddress::splitAddressList(text());
         for (const QString &address : addresses) {
-            Akonadi::ContactGroupSearchJob *job = new Akonadi::ContactGroupSearchJob();
+            auto job = new Akonadi::ContactGroupSearchJob();
             connect(job, &Akonadi::ContactGroupSearchJob::result, this, &AddresseeLineEdit::slotGroupSearchResult);
             d->mightBeGroupJobsAdd(job);
             job->setQuery(Akonadi::ContactGroupSearchJob::Name, address);
@@ -912,14 +904,14 @@ void AddresseeLineEdit::slotEditingFinished()
 
 void AddresseeLineEdit::slotGroupSearchResult(KJob *job)
 {
-    Akonadi::ContactGroupSearchJob *searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
+    auto searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
 
     // Laurent I don't understand why Akonadi::ContactGroupSearchJob send two "result(...)" signal. For the moment
     // avoid to go in this method twice, until I understand it.
     if (!d->mightBeGroupJobs().contains(searchJob)) {
         return;
     }
-    //Q_ASSERT(d->mMightBeGroupJobs.contains(searchJob));
+    // Q_ASSERT(d->mMightBeGroupJobs.contains(searchJob));
     d->mightBeGroupJobsRemoveOne(searchJob);
 
     const KContacts::ContactGroup::List contactGroups = searchJob->contactGroups();
@@ -941,7 +933,7 @@ void AddresseeLineEdit::expandGroups()
 
     const KContacts::ContactGroup::List lstGroups = d->groups();
     for (const KContacts::ContactGroup &group : lstGroups) {
-        Akonadi::ContactGroupExpandJob *expandJob = new Akonadi::ContactGroupExpandJob(group);
+        auto expandJob = new Akonadi::ContactGroupExpandJob(group);
         connect(expandJob, &Akonadi::ContactGroupExpandJob::result, this, &AddresseeLineEdit::groupExpandResult);
         addresses.removeAll(group.name());
         expandJob->start();
