@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -7,9 +7,9 @@
 
 #include "blacklistbalooemailwarningtest.h"
 #include "../blacklistbalooemailwarning.h"
-#include <QTest>
-#include <QSignalSpy>
 #include <QAction>
+#include <QSignalSpy>
+#include <QTest>
 
 BlackListBalooEmailWarningTest::BlackListBalooEmailWarningTest(QObject *parent)
     : QObject(parent)
@@ -27,10 +27,10 @@ void BlackListBalooEmailWarningTest::shouldHaveDefaultValue()
     QVERIFY(!warning.isCloseButtonVisible());
     QVERIFY(warning.wordWrap());
 
-    auto *save = warning.findChild<QAction *>(QStringLiteral("saveblacklist"));
+    auto save = warning.findChild<QAction *>(QStringLiteral("saveblacklist"));
     QVERIFY(save);
 
-    auto *search = warning.findChild<QAction *>(QStringLiteral("search"));
+    auto search = warning.findChild<QAction *>(QStringLiteral("search"));
     QVERIFY(search);
 }
 
@@ -39,7 +39,7 @@ void BlackListBalooEmailWarningTest::shouldEmitSaveChanges()
     PimCommon::BlackListBalooEmailWarning warning;
     QSignalSpy spy1(&warning, &PimCommon::BlackListBalooEmailWarning::saveChanges);
 
-    auto *save = warning.findChild<QAction *>(QStringLiteral("saveblacklist"));
+    auto save = warning.findChild<QAction *>(QStringLiteral("saveblacklist"));
     save->trigger();
     QCOMPARE(spy1.count(), 1);
 }
@@ -49,7 +49,7 @@ void BlackListBalooEmailWarningTest::shouldEmitNewSearch()
     PimCommon::BlackListBalooEmailWarning warning;
     QSignalSpy spy1(&warning, &PimCommon::BlackListBalooEmailWarning::newSearch);
 
-    auto *search = warning.findChild<QAction *>(QStringLiteral("search"));
+    auto search = warning.findChild<QAction *>(QStringLiteral("search"));
     search->trigger();
     QCOMPARE(spy1.count(), 1);
 }
