@@ -1,37 +1,24 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef BLACKLISTBALOOEMAILLIST_H
-#define BLACKLISTBALOOEMAILLIST_H
+#pragma once
 
+#include "pimcommonakonadi_private_export.h"
+#include <QHash>
 #include <QListWidget>
 #include <QListWidgetItem>
-#include <QHash>
-#include "pimcommonakonadi_private_export.h"
 
-namespace PimCommon {
+namespace PimCommon
+{
 class PIMCOMMONAKONADI_TESTS_EXPORT BlackListBalooEmailListItem : public QListWidgetItem
 {
 public:
     explicit BlackListBalooEmailListItem(QListWidget *parent = nullptr);
-    ~BlackListBalooEmailListItem();
+    ~BlackListBalooEmailListItem() override;
 
     Q_REQUIRED_RESULT bool initializeStatus() const;
     void setInitializeStatus(bool initializeStatus);
@@ -53,6 +40,7 @@ public:
 
     void setExcludeDomain(const QStringList &domain);
     Q_REQUIRED_RESULT int setEmailFound(const QStringList &);
+
 protected:
     void paintEvent(QPaintEvent *event) override;
 
@@ -67,4 +55,3 @@ private:
 };
 }
 
-#endif // BLACKLISTBALOOEMAILLIST_H
