@@ -5,10 +5,10 @@
 */
 
 #include "checkedcollectionwidget.h"
-#include <CollectionFilterProxyModel>
+#include <Akonadi/CollectionFilterProxyModel>
 
-#include <EntityTreeModel>
-#include <Monitor>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/Monitor>
 #include <QSortFilterProxyModel>
 
 #include <KCheckableProxyModel>
@@ -40,7 +40,7 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     , d(new PimCommon::CheckedCollectionWidgetPrivate)
 {
     auto vbox = new QVBoxLayout(this);
-    vbox->setContentsMargins(0, 0, 0, 0);
+    vbox->setContentsMargins({});
 
     // Create a new change recorder.
     auto monitor = new Akonadi::Monitor(this);
@@ -85,10 +85,7 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     vbox->addWidget(d->mFolderView);
 }
 
-CheckedCollectionWidget::~CheckedCollectionWidget()
-{
-    delete d;
-}
+CheckedCollectionWidget::~CheckedCollectionWidget() = default;
 
 Akonadi::EntityTreeModel *CheckedCollectionWidget::entityTreeModel() const
 {
