@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "genericplugininterface.h"
@@ -36,10 +24,7 @@ GenericPluginInterface::GenericPluginInterface(QObject *parent)
 {
 }
 
-GenericPluginInterface::~GenericPluginInterface()
-{
-    delete d;
-}
+GenericPluginInterface::~GenericPluginInterface() = default;
 
 void GenericPluginInterface::setActionTypes(const QVector<ActionType> &type)
 {
@@ -48,7 +33,7 @@ void GenericPluginInterface::setActionTypes(const QVector<ActionType> &type)
 
 void GenericPluginInterface::addActionType(ActionType type)
 {
-    //TODO check already existence ?
+    // TODO check already existence ?
     d->actionTypes.append(type);
 }
 
@@ -59,31 +44,31 @@ QVector<ActionType> GenericPluginInterface::actionTypes() const
 
 void GenericPluginInterface::updateActions(int numberOfSelectedItems, int numberOfSelectedCollections)
 {
-    Q_UNUSED(numberOfSelectedItems);
-    Q_UNUSED(numberOfSelectedCollections);
+    Q_UNUSED(numberOfSelectedItems)
+    Q_UNUSED(numberOfSelectedCollections)
 }
 
 void GenericPluginInterface::setCurrentItems(const Akonadi::Item::List &items)
 {
-    Q_UNUSED(items);
+    Q_UNUSED(items)
 }
 
 void GenericPluginInterface::setItems(const Akonadi::Item::List &items)
 {
-    Q_UNUSED(items);
+    Q_UNUSED(items)
 }
 
 void GenericPluginInterface::setCurrentCollection(const Akonadi::Collection &col)
 {
-    Q_UNUSED(col);
+    Q_UNUSED(col)
 }
 
 void GenericPluginInterface::setCollections(const Akonadi::Collection::List &cols)
 {
-    Q_UNUSED(cols);
+    Q_UNUSED(cols)
 }
 
-PimCommon::GenericPluginInterface::RequireTypes GenericPluginInterface::requires() const
+PimCommon::GenericPluginInterface::RequireTypes GenericPluginInterface::requiresFeatures() const
 {
     return None;
 }
