@@ -1,27 +1,15 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "imapresourcecapabilitiesmanager.h"
 #include "pimcommonakonadi_debug.h"
 #include "util/pimutil.h"
 
-#include <AkonadiCore/AgentManager>
-#include <AkonadiCore/ServerManager>
+#include <Akonadi/AgentManager>
+#include <Akonadi/ServerManager>
 
 #include <QDBusConnection>
 #include <QDBusInterface>
@@ -51,17 +39,14 @@ void ImapResourceCapabilitiesManager::slotInstanceRemoved(const Akonadi::AgentIn
 
 void ImapResourceCapabilitiesManager::searchCapabilities(const QString &identifier)
 {
-    //By default makes it as true.
+    // By default makes it as true.
     mImapResource.insert(identifier, true);
-    const QString service
-        = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, identifier);
-    QDBusInterface iface(service,
-                         QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"),
-                         QDBusConnection::sessionBus(), this);
+    const QString service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, identifier);
+    QDBusInterface iface(service, QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"), QDBusConnection::sessionBus(), this);
 
     if (iface.isValid()) {
         QDBusPendingCall call = iface.asyncCall(QStringLiteral("serverCapabilities"));
-        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+        auto watcher = new QDBusPendingCallWatcher(call, this);
         watcher->setProperty("identifier", identifier);
         connect(watcher, &QDBusPendingCallWatcher::finished, this, &ImapResourceCapabilitiesManager::slotCapabilities);
     } else {
